import { View, Text, FlatList, Pressable, ScrollView, TextInput, TouchableOpacity, Linking, Alert } from 'react-native';
import React, { useEffect, useState } from 'react';
import { resetLogItems, toggleDebugger, useDebugItems } from './utils';
import Clipboard from '@react-native-clipboard/clipboard';
import { useShowDebugger } from './utils/useShowDebugger';
import { DebuggerItem } from './components/DebuggerItem';
import { styles, itemColorByType } from './styles';
import { DebuggerState } from './state';
export * from './utils';
export * from './components';
export function multiply(a, b) {
  return Promise.resolve(a * b);
}

const Item = _ref => {
  let {
    item
  } = _ref;
  const [visible, setVisible] = useState(false);

  const handleCopyPress = () => Clipboard.setString(JSON.stringify(item));

  const colorByType = itemColorByType(item.logType);
  const textColor = {
    color: colorByType
  };
  const iconColor = {
    backgroundColor: colorByType
  };
  return /*#__PURE__*/React.createElement(View, {
    style: styles.itemWrapper
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.itemHeader
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.itemIcon, iconColor]
  }), /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(Text, {
    selectable: true,
    style: [styles.itemLabel, textColor]
  }, item.label), /*#__PURE__*/React.createElement(Text, {
    selectable: true,
    style: [styles.itemTime, textColor]
  }, item.timestamp), Boolean(item.type) && /*#__PURE__*/React.createElement(Text, {
    selectable: true,
    style: [styles.itemType, textColor]
  }, item.type))), /*#__PURE__*/React.createElement(ScrollView, {
    style: visible ? styles.itemScrollWrapperVisible : styles.itemScrollWrapper,
    contentContainerStyle: item.itemScroll,
    horizontal: true
  }, /*#__PURE__*/React.createElement(DebuggerItem, {
    onToggle: setVisible,
    item: item.data
  })), visible && /*#__PURE__*/React.createElement(Pressable, {
    onPress: handleCopyPress,
    style: styles.itemCopyBtn
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.itemCopyText
  }, "Copy")));
};

const Separator = () => /*#__PURE__*/React.createElement(View, {
  style: styles.separator
});

const EmptySection = () => /*#__PURE__*/React.createElement(View, {
  style: styles.emptyWrapper
}, /*#__PURE__*/React.createElement(Text, {
  style: styles.emptyText
}, "No events captured yet"));

const keyExtractor = _ref2 => {
  let {
    id
  } = _ref2;
  return `${id}`;
};

const renderItem = _ref3 => {
  let {
    item
  } = _ref3;
  return /*#__PURE__*/React.createElement(Item, {
    item: item
  });
};

export const Debugger = /*#__PURE__*/React.memo(_ref4 => {
  let {
    getGlobalState
  } = _ref4;
  const [debugItems] = useDebugItems();
  const [show] = useShowDebugger();
  useEffect(() => {
    DebuggerState.isMounted = true;
    return () => {
      DebuggerState.isMounted = false;
    };
  }, []);
  useEffect(() => {
    DebuggerState.getGlobalState = getGlobalState;
  }, [getGlobalState]);

  const handleClose = () => toggleDebugger(false);

  const handleGetGlobalState = () => getGlobalState && Clipboard.setString(JSON.stringify(getGlobalState === null || getGlobalState === void 0 ? void 0 : getGlobalState()));

  const handleCopyItems = () => {
    Clipboard.setString(JSON.stringify(debugItems));
  };

  const [sendTo, setSendTo] = useState('');

  const handleSend = async () => {
    if (!sendTo) return;

    if (sendTo.includes('@')) {
      const canSendEmail = await Linking.canOpenURL(`mailto:${sendTo}`);

      if (canSendEmail) {
        Linking.openURL(`mailto:${sendTo}?subject=logs${new Date().toISOString()}&body=${JSON.stringify(debugItems)}`);
      } else {
        Alert.alert('Cannot send email');
      }
    } else {
      // 	https://webhook.site/ab0c53e9-a21e-4b46-ab4c-02fe9b6cac93
      fetch(sendTo.trim(), {
        method: 'POST',
        body: JSON.stringify(debugItems)
      }).then(() => {
        Alert.alert('Success', `Logs sent to ${sendTo.trim()}`);
      }).catch(() => {
        Alert.alert('Error', `Could not send logs to ${sendTo.trim()}`);
      });
    }
  };

  return show ? /*#__PURE__*/React.createElement(View, {
    style: styles.wrapper
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.titleWrapper
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.title
  }, "QA DEBUGGER")), /*#__PURE__*/React.createElement(FlatList, {
    keyExtractor: keyExtractor,
    contentContainerStyle: styles.flex,
    ItemSeparatorComponent: Separator,
    data: debugItems,
    ListEmptyComponent: EmptySection,
    renderItem: renderItem
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.buttonSection
  }, /*#__PURE__*/React.createElement(Pressable, {
    onPress: handleCopyItems,
    style: styles.button
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.buttonText
  }, "Copy items")), /*#__PURE__*/React.createElement(Pressable, {
    onPress: resetLogItems,
    style: [styles.button, styles.centralButton]
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.buttonText
  }, "Clear")), /*#__PURE__*/React.createElement(Pressable, {
    onPress: handleClose,
    style: styles.button
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.buttonText
  }, "Close"))), Boolean(getGlobalState) && /*#__PURE__*/React.createElement(View, {
    style: styles.buttonSection
  }, /*#__PURE__*/React.createElement(Pressable, {
    onPress: handleGetGlobalState,
    style: styles.button
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.buttonText
  }, "Copy global state"))), /*#__PURE__*/React.createElement(View, {
    style: styles.buttonSection
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.buttonText
  }, " Send to"), /*#__PURE__*/React.createElement(TextInput, {
    style: styles.sendToInput,
    value: sendTo,
    onChangeText: setSendTo
  }), Boolean(sendTo) && /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: styles.sendButton,
    onPress: handleSend
  }, /*#__PURE__*/React.createElement(Text, {
    style: styles.buttonText
  }, "Send")))) : null;
});
//# sourceMappingURL=index.js.map